@@ -98,7 +98,7 @@ class Exceptions:
 
 class KafkaClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html)
     """
 
@@ -116,7 +116,7 @@ class KafkaClient(BaseClient):
         """
         Associates one or more Scram Secrets with an Amazon MSK cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.batch_associate_scram_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.batch_associate_scram_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#batch_associate_scram_secret)
         """
 
@@ -126,7 +126,7 @@ class KafkaClient(BaseClient):
         """
         Disassociates one or more Scram Secrets from an Amazon MSK cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.batch_disassociate_scram_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.batch_disassociate_scram_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#batch_disassociate_scram_secret)
         """
 
@@ -134,7 +134,7 @@ class KafkaClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#can_paginate)
         """
 
@@ -145,18 +145,18 @@ class KafkaClient(BaseClient):
         ClusterName: str,
         KafkaVersion: str,
         NumberOfBrokerNodes: int,
-        ClientAuthentication: "ClientAuthenticationTypeDef" = None,
-        ConfigurationInfo: "ConfigurationInfoTypeDef" = None,
-        EncryptionInfo: "EncryptionInfoTypeDef" = None,
-        EnhancedMonitoring: EnhancedMonitoringType = None,
-        OpenMonitoring: "OpenMonitoringInfoTypeDef" = None,
-        LoggingInfo: "LoggingInfoTypeDef" = None,
-        Tags: Mapping[str, str] = None
+        ClientAuthentication: "ClientAuthenticationTypeDef" = ...,
+        ConfigurationInfo: "ConfigurationInfoTypeDef" = ...,
+        EncryptionInfo: "EncryptionInfoTypeDef" = ...,
+        EnhancedMonitoring: EnhancedMonitoringType = ...,
+        OpenMonitoring: "OpenMonitoringInfoTypeDef" = ...,
+        LoggingInfo: "LoggingInfoTypeDef" = ...,
+        Tags: Mapping[str, str] = ...
     ) -> CreateClusterResponseTypeDef:
         """
         Creates a new MSK cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.create_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.create_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#create_cluster)
         """
 
@@ -165,24 +165,24 @@ class KafkaClient(BaseClient):
         *,
         Name: str,
         ServerProperties: Union[bytes, IO[bytes], StreamingBody],
-        Description: str = None,
-        KafkaVersions: Sequence[str] = None
+        Description: str = ...,
+        KafkaVersions: Sequence[str] = ...
     ) -> CreateConfigurationResponseTypeDef:
         """
         Creates a new MSK configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.create_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.create_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#create_configuration)
         """
 
     def delete_cluster(
-        self, *, ClusterArn: str, CurrentVersion: str = None
+        self, *, ClusterArn: str, CurrentVersion: str = ...
     ) -> DeleteClusterResponseTypeDef:
         """
         Deletes the MSK cluster specified by the Amazon Resource Name (ARN) in the
         request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.delete_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.delete_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#delete_cluster)
         """
 
@@ -190,7 +190,7 @@ class KafkaClient(BaseClient):
         """
         Deletes an MSK Configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.delete_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.delete_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#delete_configuration)
         """
 
@@ -199,7 +199,7 @@ class KafkaClient(BaseClient):
         Returns a description of the MSK cluster whose Amazon Resource Name (ARN) is
         specified in the request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.describe_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.describe_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#describe_cluster)
         """
 
@@ -209,7 +209,7 @@ class KafkaClient(BaseClient):
         """
         Returns a description of the cluster operation specified by the ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.describe_cluster_operation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.describe_cluster_operation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#describe_cluster_operation)
         """
 
@@ -217,7 +217,7 @@ class KafkaClient(BaseClient):
         """
         Returns a description of this MSK configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.describe_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.describe_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#describe_configuration)
         """
 
@@ -227,21 +227,21 @@ class KafkaClient(BaseClient):
         """
         Returns a description of this revision of the configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.describe_configuration_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.describe_configuration_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#describe_configuration_revision)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#generate_presigned_url)
         """
 
@@ -249,88 +249,88 @@ class KafkaClient(BaseClient):
         """
         A list of brokers that a client application can use to bootstrap.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.get_bootstrap_brokers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.get_bootstrap_brokers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#get_bootstrap_brokers)
         """
 
     def get_compatible_kafka_versions(
-        self, *, ClusterArn: str = None
+        self, *, ClusterArn: str = ...
     ) -> GetCompatibleKafkaVersionsResponseTypeDef:
         """
         Gets the Apache Kafka versions to which you can update the MSK cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.get_compatible_kafka_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.get_compatible_kafka_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#get_compatible_kafka_versions)
         """
 
     def list_cluster_operations(
-        self, *, ClusterArn: str, MaxResults: int = None, NextToken: str = None
+        self, *, ClusterArn: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListClusterOperationsResponseTypeDef:
         """
         Returns a list of all the operations that have been performed on the specified
         MSK cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.list_cluster_operations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.list_cluster_operations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_cluster_operations)
         """
 
     def list_clusters(
-        self, *, ClusterNameFilter: str = None, MaxResults: int = None, NextToken: str = None
+        self, *, ClusterNameFilter: str = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> ListClustersResponseTypeDef:
         """
         Returns a list of all the MSK clusters in the current Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.list_clusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.list_clusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_clusters)
         """
 
     def list_configuration_revisions(
-        self, *, Arn: str, MaxResults: int = None, NextToken: str = None
+        self, *, Arn: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListConfigurationRevisionsResponseTypeDef:
         """
         Returns a list of all the MSK configurations in this Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.list_configuration_revisions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.list_configuration_revisions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_configuration_revisions)
         """
 
     def list_configurations(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListConfigurationsResponseTypeDef:
         """
         Returns a list of all the MSK configurations in this Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.list_configurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.list_configurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_configurations)
         """
 
     def list_kafka_versions(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListKafkaVersionsResponseTypeDef:
         """
         Returns a list of Kafka versions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.list_kafka_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.list_kafka_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_kafka_versions)
         """
 
     def list_nodes(
-        self, *, ClusterArn: str, MaxResults: int = None, NextToken: str = None
+        self, *, ClusterArn: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListNodesResponseTypeDef:
         """
         Returns a list of the broker nodes in the cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.list_nodes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.list_nodes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_nodes)
         """
 
     def list_scram_secrets(
-        self, *, ClusterArn: str, MaxResults: int = None, NextToken: str = None
+        self, *, ClusterArn: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListScramSecretsResponseTypeDef:
         """
         Returns a list of the Scram Secrets associated with an Amazon MSK cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.list_scram_secrets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.list_scram_secrets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_scram_secrets)
         """
 
@@ -338,7 +338,7 @@ class KafkaClient(BaseClient):
         """
         Returns a list of the tags associated with the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_tags_for_resource)
         """
 
@@ -348,7 +348,7 @@ class KafkaClient(BaseClient):
         """
         Reboots brokers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.reboot_broker)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.reboot_broker)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#reboot_broker)
         """
 
@@ -356,7 +356,7 @@ class KafkaClient(BaseClient):
         """
         Adds tags to the specified MSK resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#tag_resource)
         """
 
@@ -364,7 +364,7 @@ class KafkaClient(BaseClient):
         """
         Removes the tags associated with the keys that are provided in the query.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#untag_resource)
         """
 
@@ -374,7 +374,7 @@ class KafkaClient(BaseClient):
         """
         Updates the number of broker nodes in the cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.update_broker_count)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.update_broker_count)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_broker_count)
         """
 
@@ -388,7 +388,7 @@ class KafkaClient(BaseClient):
         """
         Updates the EBS storage associated with MSK brokers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.update_broker_storage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.update_broker_storage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_broker_storage)
         """
 
@@ -398,7 +398,7 @@ class KafkaClient(BaseClient):
         """
         Updates EC2 instance type.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.update_broker_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.update_broker_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_broker_type)
         """
 
@@ -409,7 +409,7 @@ class KafkaClient(BaseClient):
         Updates the cluster with the configuration that is specified in the request
         body.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.update_cluster_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.update_cluster_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_cluster_configuration)
         """
 
@@ -419,12 +419,12 @@ class KafkaClient(BaseClient):
         ClusterArn: str,
         CurrentVersion: str,
         TargetKafkaVersion: str,
-        ConfigurationInfo: "ConfigurationInfoTypeDef" = None
+        ConfigurationInfo: "ConfigurationInfoTypeDef" = ...
     ) -> UpdateClusterKafkaVersionResponseTypeDef:
         """
         Updates the Apache Kafka version for the cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.update_cluster_kafka_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.update_cluster_kafka_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_cluster_kafka_version)
         """
 
@@ -433,12 +433,12 @@ class KafkaClient(BaseClient):
         *,
         Arn: str,
         ServerProperties: Union[bytes, IO[bytes], StreamingBody],
-        Description: str = None
+        Description: str = ...
     ) -> UpdateConfigurationResponseTypeDef:
         """
         Updates an MSK configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.update_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.update_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_configuration)
         """
 
@@ -447,14 +447,14 @@ class KafkaClient(BaseClient):
         *,
         ClusterArn: str,
         CurrentVersion: str,
-        EnhancedMonitoring: EnhancedMonitoringType = None,
-        OpenMonitoring: "OpenMonitoringInfoTypeDef" = None,
-        LoggingInfo: "LoggingInfoTypeDef" = None
+        EnhancedMonitoring: EnhancedMonitoringType = ...,
+        OpenMonitoring: "OpenMonitoringInfoTypeDef" = ...,
+        LoggingInfo: "LoggingInfoTypeDef" = ...
     ) -> UpdateMonitoringResponseTypeDef:
         """
         Updates the monitoring settings for the cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.update_monitoring)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.update_monitoring)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_monitoring)
         """
 
@@ -463,13 +463,13 @@ class KafkaClient(BaseClient):
         *,
         ClusterArn: str,
         CurrentVersion: str,
-        ClientAuthentication: "ClientAuthenticationTypeDef" = None,
-        EncryptionInfo: "EncryptionInfoTypeDef" = None
+        ClientAuthentication: "ClientAuthenticationTypeDef" = ...,
+        EncryptionInfo: "EncryptionInfoTypeDef" = ...
     ) -> UpdateSecurityResponseTypeDef:
         """
         Updates the security settings for the cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Client.update_security)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Client.update_security)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_security)
         """
 
@@ -478,14 +478,14 @@ class KafkaClient(BaseClient):
         self, operation_name: Literal["list_cluster_operations"]
     ) -> ListClusterOperationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclusteroperationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_clusters"]) -> ListClustersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Paginator.ListClusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Paginator.ListClusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclusterspaginator)
         """
 
@@ -494,7 +494,7 @@ class KafkaClient(BaseClient):
         self, operation_name: Literal["list_configuration_revisions"]
     ) -> ListConfigurationRevisionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listconfigurationrevisionspaginator)
         """
 
@@ -503,7 +503,7 @@ class KafkaClient(BaseClient):
         self, operation_name: Literal["list_configurations"]
     ) -> ListConfigurationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listconfigurationspaginator)
         """
 
@@ -512,14 +512,14 @@ class KafkaClient(BaseClient):
         self, operation_name: Literal["list_kafka_versions"]
     ) -> ListKafkaVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listkafkaversionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_nodes"]) -> ListNodesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Paginator.ListNodes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Paginator.ListNodes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listnodespaginator)
         """
 
@@ -528,6 +528,6 @@ class KafkaClient(BaseClient):
         self, operation_name: Literal["list_scram_secrets"]
     ) -> ListScramSecretsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listscramsecretspaginator)
         """
